Struct mpl_candy_machine::accounts::UpdateCandyMachine
source · pub struct UpdateCandyMachine {
pub candy_machine: Pubkey,
pub authority: Pubkey,
pub wallet: Pubkey,
}Expand description
Generated client accounts for UpdateCandyMachine.
Fields
candy_machine: Pubkeywallet: PubkeyTrait Implementations
sourceimpl BorshSerialize for UpdateCandyMachine
impl BorshSerialize for UpdateCandyMachine
sourceimpl ToAccountMetas for UpdateCandyMachine
impl ToAccountMetas for UpdateCandyMachine
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for UpdateCandyMachine
impl Send for UpdateCandyMachine
impl Sync for UpdateCandyMachine
impl Unpin for UpdateCandyMachine
impl UnwindSafe for UpdateCandyMachine