Struct mpl_candy_machine::state::Creator
source · pub struct Creator {
pub address: Pubkey,
pub verified: bool,
pub share: u8,
}Fields
address: Pubkeyverified: boolTrait Implementations
sourceimpl BorshDeserialize for Creator
impl BorshDeserialize for Creator
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,