Struct mpl_candy_machine::state::EndSettings
source · pub struct EndSettings {
pub end_setting_type: EndSettingType,
pub number: u64,
}Fields
end_setting_type: EndSettingTypenumber: u64Trait Implementations
sourceimpl BorshDeserialize for EndSettings
impl BorshDeserialize for EndSettings
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for EndSettings
impl BorshSerialize for EndSettings
sourceimpl Clone for EndSettings
impl Clone for EndSettings
sourcefn clone(&self) -> EndSettings
fn clone(&self) -> EndSettings
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl RefUnwindSafe for EndSettings
impl Send for EndSettings
impl Sync for EndSettings
impl Unpin for EndSettings
impl UnwindSafe for EndSettings