Struct mpl_candy_machine::state::HiddenSettings
source · pub struct HiddenSettings {
pub name: String,
pub uri: String,
pub hash: [u8; 32],
}Expand description
Hidden Settings for large mints used with offline data.
Fields
name: Stringuri: Stringhash: [u8; 32]Trait Implementations
sourceimpl BorshDeserialize for HiddenSettings
impl BorshDeserialize for HiddenSettings
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for HiddenSettings
impl BorshSerialize for HiddenSettings
sourceimpl Clone for HiddenSettings
impl Clone for HiddenSettings
sourcefn clone(&self) -> HiddenSettings
fn clone(&self) -> HiddenSettings
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for HiddenSettings
impl Debug for HiddenSettings
sourceimpl Default for HiddenSettings
impl Default for HiddenSettings
sourcefn default() -> HiddenSettings
fn default() -> HiddenSettings
Returns the “default value” for a type. Read more